OC.L10N.register(
    "files",
    {
    "File could not be found" : "Súbor nie je možné nájsť",
    "Move or copy" : "Presunúť alebo kopírovať",
    "Download" : "Stiahnuť",
    "Delete" : "Zmazať",
    "Tags" : "Štítky",
    "Show list view" : "Zobraziť ako zoznam",
    "Show grid view" : "Zobraziť v mriežke",
    "Home" : "Domov",
    "Close" : "Zavrieť",
    "Could not create folder \"{dir}\"" : "Nemožno vytvoriť priečinok \"{dir}\"",
    "This will stop your current uploads." : "Toto zastaví práve prebiehajúce nahrávania.",
    "Upload cancelled." : "Odosielanie je zrušené.",
    "Processing files …" : "Spracovávam súbory ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nemožno nahrať súbor {filename}, pretože je to priečinok, alebo má 0 bitov",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Nie je dostatok voľného miesta, chcete nahrať {size1} ale k dispozíciji je len {size2}",
    "Target folder \"{dir}\" does not exist any more" : "Cieľový priečinok \"{dir}\" už neexistuje",
    "Not enough free space" : "Nedostatok voľného miesta",
    "An unknown error has occurred" : "Vyskytla sa neznáma chyba",
    "File could not be uploaded" : "Súbor nemôže byť nahraný",
    "Uploading …" : "Nahrávanie...",
    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
    "Uploading … ({currentNumber}/{total})" : "Nahrávanie... ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} z {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Nahrávanie tejto položky nie je podporované",
    "Target folder does not exist any more" : "Cieľový priečinok už neexistuje",
    "Operation is blocked by access control" : "Činnosť je blokovaná kontrolou prístupu",
    "Error when assembling chunks, status code {status}" : "Chyba pri zostavovaní kusov, kód chyby {status}",
    "Actions" : "Akcie",
    "Rename" : "Premenovať",
    "Move" : "Presunúť",
    "Copy" : "Kopírovať",
    "Choose target folder" : "Vyberte cieľový priečinok",
    "Set reminder" : "Nastaviť pripomienku",
    "Edit locally" : "Editovať lokálne",
    "Open" : "Otvoriť",
    "Could not load info for file \"{file}\"" : "Nebolo možné načítať informácie súboru \"{file}\"",
    "Files" : "Súbory",
    "Details" : "Podrobnosti",
    "Please select tag(s) to add to the selection" : "Prosím vyberte štítok (štítky) pre pridanie do výberu",
    "Apply tag(s) to selection" : "Aplikovať štítok(štítky) do výberu",
    "Select directory \"{dirName}\"" : "Vybrať priečinok \"{dirName}\"",
    "Select file \"{fileName}\"" : "Vybrať súbor \"{fileName}\"",
    "Pending" : "Čaká",
    "Unable to determine date" : "Nemožno určiť dátum",
    "This operation is forbidden" : "Táto operácia je zakázaná",
    "This directory is unavailable, please check the logs or contact the administrator" : "Priečinok je nedostupný, skontrolujte prosím logy, alebo kontaktujte správcu",
    "Storage is temporarily not available" : "Úložisko je dočasne nedostupné",
    "Could not move \"{file}\", target exists" : "Nie je možné presunúť \"{file}\", cieľ už existuje",
    "Could not move \"{file}\"" : "Nie je možné presunúť \"{file}\"",
    "copy" : "kópia",
    "Could not copy \"{file}\", target exists" : "Nie je možné kopírovať \"{file}\", cieľ už existuje",
    "Could not copy \"{file}\"" : "Nie je možné skopírovať \"{file}\"",
    "Copied {origin} inside {destination}" : "Skopírované {origin} do {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "Skopírované {origin} a {nbfiles} ostatných súborov do {destination}",
    "Failed to redirect to client" : "Nepodarilo sa presmerovať na klienta",
    "{newName} already exists" : "{newName} už existuje",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nie je možné premenovať \"{fileName}\", cieľ už neexistuje",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{targetName}\" je už použitý v priečinku \"{dir}\". Zvoľte prosím iný názov.",
    "Could not rename \"{fileName}\"" : "Nie je možné premenovať \"{file}\"",
    "Could not create file \"{file}\"" : "Nie je možné vytvoriť súbor \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nie je možné vytvoriť súbor \"{file}\" lebo už existuje",
    "Could not create folder \"{dir}\" because it already exists" : "Nie je možné vytvoriť priečinok \"{dir}\" lebo už existuje",
    "Could not fetch file details \"{file}\"" : "Podrobnosti o súbore „{file}“ sa nepodarilo načítať",
    "Error deleting file \"{fileName}\"." : "Chyba pri mazaní súboru \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Žiadne výsledky vyhľadávania v ostatných priečinkoch pre {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Ak chcete hľadať v iných priečinkoch, zadajte viac ako dva znaky",
    "Name" : "Názov",
    "Size" : "Veľkosť",
    "Modified" : "Upravené",
    "_%n folder_::_%n folders_" : ["%n priečinok","%n priečinky","%n priečinkov","%n priečinkov"],
    "_%n file_::_%n files_" : ["%n súbor","%n súbory","%n súborov","%n súborov"],
    "{dirs} and {files}" : "{dirs} a {files}",
    "_including %n hidden_::_including %n hidden_" : ["vrátane %n skytého","vrátane %n skrytých","vrátane %n skrytých","vrátane %n skrytých"],
    "You do not have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvárať súbory",
    "_Uploading %n file_::_Uploading %n files_" : ["Nahrávam %n súbor","Nahrávam %n súbory","Nahrávam %n súborov","Nahrávam %n súborov"],
    "New" : "Nový",
    "New file/folder menu" : "Ponuka nového súboru/priečinka",
    "Select file range" : "Vybrať rozsah súborov",
    "{used}%" : "{used}%",
    "{used} of {quota} used" : "použitých {used} z {quota}",
    "{used} used" : "{used} použitých",
    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
    "\"/\" is not allowed inside a file name." : "Znak \"/\" nie je povolený v názve súboru.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Úložisko používateľa {owner} je plné, súbory sa viac nedajú aktualizovať ani synchronizovať!",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Priečinok skupiny \"{mountPoint}\" je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Externé úložisko \"{mountPoint}\" je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Vaše úložisko je plné, súbory nemožno aktualizovať ani synchronizovať!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Úloisko používateľa {owner} je takmer plné ({usedSpacePercent}%)",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Priečinok skupiny \"{mountPoint}\" je takmer plné ({usedSpacePercent}%)",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Externé úložisko \"{mountPoint}\" je takmer plné ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)." : "Vaše úložisko je takmer plné ({usedSpacePercent}%)",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedá \"{filter}\"","odpovedajú \"{filter}\""],
    "View in folder" : "Zobraziť v priečinku",
    "Path" : "Cesta",
    "_%n byte_::_%n bytes_" : ["%n bajt","%n bajty","%n bajtov","%n bajtov"],
    "Favorited" : "Pridané k obľúbeným",
    "Favorite" : "Obľúbené",
    "New folder" : "Nový priečinok",
    "Create new folder" : "Vytvoriť nový priečinok",
    "Upload file" : "Nahrať súbor",
    "Recent" : "Nedávne",
    "Not favorited" : "Nie je obľúbený",
    "Remove from favorites" : "Odstrániť z obľúbených",
    "Add to favorites" : "Pridať do obľúbených",
    "An error occurred while trying to update the tags" : "Pri pokuse o aktualizáciu štítkov došlo k chybe",
    "Added to favorites" : "Pridané do obľúbených",
    "Removed from favorites" : "Odstránené z obľúbených",
    "You added {file} to your favorites" : "Pridali ste {file} do vašich obľúbených",
    "You removed {file} from your favorites" : "Odstránili ste {file} z vašich obľúbených",
    "Favorites" : "Obľúbené",
    "File changes" : "Zmeny v súboroch",
    "Created by {user}" : "Vytvorené užívateľom {user}",
    "Changed by {user}" : "Zmenené užívateľom {user}",
    "Deleted by {user}" : "Zmazané užívateľom {user}",
    "Restored by {user}" : "Obnovené užívateľom {user}",
    "Renamed by {user}" : "Premenované užívateľom {user}",
    "Moved by {user}" : "Presunuté užívateľom {user}",
    "You created {file}" : "Vytvorili ste súbor {file}",
    "You created an encrypted file in {file}" : "Vytvorili ste zašifrovaný súbor  {file}",
    "{user} created {file}" : "{user} vytvoril súbor {file}",
    "{user} created an encrypted file in {file}" : "{user} vytvoril šifrovaný súbor {file}",
    "{file} was created in a public folder" : "{file} bol vytvorený vo verejnom priečinku",
    "You changed {file}" : "Zmenili ste {file}",
    "You changed an encrypted file in {file}" : "Zmenili ste šifrovaný súbor {file}",
    "{user} changed {file}" : "{user} zmenil {file}",
    "{user} changed an encrypted file in {file}" : "{user} zmenil šifrovaný súbor {file}",
    "You deleted {file}" : "Zmazali ste {file}",
    "You deleted an encrypted file in {file}" : "Zmazali ste šifrovaný súbor {file}",
    "{user} deleted {file}" : "{user} zmazal {file}",
    "{user} deleted an encrypted file in {file}" : "{user} zmazal šifrovaný súbor {file}",
    "You restored {file}" : "Obnovili ste {file}",
    "{user} restored {file}" : "{user} obnovil {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Premenovali ste {oldfile} (skryté) na {newfile} (skryté)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Premenovali ste {oldfile} (skryté) na {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Premenovali ste {oldfile} na {newfile} (skryté)",
    "You renamed {oldfile} to {newfile}" : "Premenovali ste {oldfile} na {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} premenoval {oldfile} (skryté) na {newfile} (skryté)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} premenoval {oldfile} (skryté) na {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} premenoval {oldfile} na {newfile} (skryté)",
    "{user} renamed {oldfile} to {newfile}" : "{user} premenoval {oldfile} na {newfile}",
    "You moved {oldfile} to {newfile}" : "Presunuli ste {oldfile} do {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} presunul {oldfile} do {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Súbor bol pridaný alebo odstránený z vašich <strong>obľúbených</strong>",
    "A file or folder has been <strong>changed</strong>" : "Súbor alebo priečinok bol <strong>zmenený</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Obľúbený súbor alebo priečinok bol <strong>zmenený</strong>",
    "Upload (max. %s)" : "Nahrať (max. %s)",
    "Accept" : "Prijať",
    "Reject" : "Odmietnuť",
    "Incoming ownership transfer from {user}" : "Prichádzajúci prevod vlastníctva od {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Chcete prijať {path}?\n\nPozn.: Proces pre prijatie môže trvať až hodinu.",
    "Ownership transfer failed" : "Prevod vlastníctva zlyhal",
    "Your ownership transfer of {path} to {user} failed." : "Prevod vlastníctva {path} od vás na {user} zlyhal.",
    "The ownership transfer of {path} from {user} failed." : "Prevod vlastníctva {path} od {user} zlyhal.",
    "Ownership transfer done" : "Prevod vlastníctva dokončený",
    "Your ownership transfer of {path} to {user} has completed." : "Prevod vami vlastnenej položky {path} na {user} bol dokončený.",
    "The ownership transfer of {path} from {user} has completed." : "Prevod vlastníctva položky {path} od {user} bol dokončený.",
    "in %s" : "v %s",
    "File Management" : "Správa súborov",
    "Reload current directory" : "Znova načítať súčasný adresár",
    "Go to the \"{dir}\" directory" : "Ísť do \"{dir}\" adresára",
    "Drag and drop files here to upload" : "Pre nahratie presuňte do tohto priestoru súbory ťahaním",
    "Your have used your space quota and cannot upload files anymore" : "Dosiahli ste limit vášho priestoru a už viac nemôžete nahrávať súbory",
    "You don’t have permission to upload or create files here" : "Nemáte oprávnenie sem nahrávať alebo vytvoriť súbory",
    "\"{displayName}\" action executed successfully" : "\"{displayName}\" akcia vykonaná úspešne",
    "\"{displayName}\" action failed" : "\"{displayName}\" akcia zlýhala",
    "Rename file" : "Premenovať súbor",
    "File name" : "Názov súboru",
    "Folder name" : "Názov priečinka",
    "This node is unavailable" : "Uzol nie je k dispozícií",
    "Download file {name}" : "Stiahnuť súbor {name}",
    "\"{name}\" is not an allowed filetype." : "\"{name}\" nie je povolený typ súboru",
    "{newName} already exists." : "{newName} už existuje.",
    "\"{char}\" is not allowed inside a file name." : "Znak \"{char}\" nie je povolený v názve súboru.",
    "Name cannot be empty" : "Názov nemôže byť prázdny",
    "Another entry with the same name already exists" : "Názov už existuje",
    "Renamed \"{oldName}\" to \"{newName}\"" : "Premenované z \"{oldName}\" na \"{newName}\"",
    "Could not rename \"{oldName}\", it does not exist any more" : "Nebolo možné premenovať  \"{oldName}\". Položka už neexistuje.",
    "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Názov \"{newName}\" sa už používa v priečinku \"{dir}\". Vyberte prosím iný názov.",
    "Could not rename \"{oldName}\"" : "Nebolo možné premenovať \"{oldName}\"",
    "Total rows summary" : "Súčet všetkých riadkov",
    "\"{displayName}\" batch action executed successfully" : "Hromadná operácia \"{displayName}\" bola úspešne vykonaná",
    "List of files and folders." : "Zoznam súborov a priečinkov.",
    "Column headers with buttons are sortable." : "Stĺpce hlavičiek s tlačidlami sú triediteľné.",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzať zoznamom.",
    "File not found" : "Súbor nenájdený",
    "Storage informations" : "Úložiskové informácie",
    "{usedQuotaByte} used" : "{usedQuotaByte} použitých",
    "{relative}% used" : "{relative}% použitých",
    "Could not refresh storage stats" : "Nebolo možné obnoviť úložiskové štatistiky",
    "Your storage is full, files can not be updated or synced anymore!" : "Vaše úložisko je plné. Súbory nemožno aktualizovať ani synchronizovať!",
    "Create" : "Vytvoriť",
    "Transfer ownership of a file or folder" : "Prevod vlastníctva súboru alebo priečinka",
    "Choose file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Change" : "Zmeniť",
    "New owner" : "Nový vlastník",
    "Choose a file or folder to transfer" : "Vyberte súbor alebo priečinok na prevod",
    "Transfer" : "Prevod",
    "Transfer {path} to {userid}" : "Previesť {path} na {userid}",
    "Invalid path selected" : "Bola vybraná neplatná cesta",
    "Unknown error" : "Neznáma chyba",
    "Ownership transfer request sent" : "Žiadosť o prevod vlastníctva bola odoslaná",
    "Cannot transfer ownership of a file or folder you do not own" : "Nie je možné preniesť vlastníctvo súboru alebo priečinka, ktorý nevlastníte",
    "Select file or folder to link to" : "Vyberte súbor alebo priečinok na ktorý odkazovať",
    "Choose {file}" : "Vyberte {file}",
    "Loading current folder" : "Načítavanie súčasného priečinka",
    "No files in here" : "Nie sú tu žiadne súbory",
    "Upload some content or sync with your devices!" : "Nahrajte nejaký obsah alebo synchronizujte dáta so svojimi zariadeniami!",
    "Go to the previous folder" : "Prejsť do predchádzajúceho priečinka",
    "Go back" : "Ísť späť",
    "Share" : "Zdieľať",
    "Shared by link" : "Sprístupnené odkazom",
    "Shared" : "Sprístupnené",
    "Switch to list view" : "Prepnúť na zobrazenie v zozname",
    "Switch to grid view" : "Prepnúť na zobrazenie v mriežke",
    "Error during upload: {message}" : "Chyba počas nahrávania: {message}",
    "Unknown error during upload" : "Neznáma chyba počas nahrávania",
    "Open the files app settings" : "Otvoriť nastavenia súborovej aplikácie",
    "Files settings" : "Nastavenia súborov",
    "File cannot be accessed" : "Súbor nie je možné sprístupniť",
    "Sort favorites first" : "Zoradiť od najobľúbenejších",
    "Show hidden files" : "Zobraziť skryté súbory",
    "Crop image previews" : "Orezať náhľady obrázkov",
    "Enable the grid view" : "Povoliť zobrazenie v mriežke",
    "Additional settings" : "Ďalšie nastavenia",
    "WebDAV" : "WebDAV",
    "WebDAV URL" : "WebDAV URL",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Use this address to access your Files via WebDAV" : "Táto adresa sa používa na prístup k vašim súborom prostredníctvom WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Ak ste povolili 2FA, musíte kliknutím sem vytvoriť a použiť nové heslo pre aplikáciu.",
    "Clipboard is not available" : "Schránka nie je prístupná",
    "WebDAV URL copied to clipboard" : "WebDAV URL skopirovaná do schránky",
    "Unable to change the favourite state of the file" : "Nie je možné zmeniť stav „obľúbené“ daného súboru",
    "Error while loading the file data" : "Chyba pri načítaní údajov súboru",
    "Pick a template for {name}" : "Vyberte šablónu pre {name}",
    "Create a new file with the selected template" : "Vytvoriť nový súbor pomocou vybranej šablóny",
    "Creating file" : "Vytvára sa súbor",
    "Blank" : "Prázdne",
    "Unable to create new file from template" : "Nemôžem vytvoriť nový súbor zo šablóny",
    "Delete permanently" : "Zmazať  natrvalo",
    "Cancel" : "Zrušiť",
    "Destination is not a folder" : "Cieľ nie je priečinok",
    "This file/folder is already in that directory" : "Tento súbor/priečinok sa už v danom adresári nachádza",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nemôžete presunúť súbor/priečinok do seba alebo do jeho podpriečinka.",
    "A file or folder with that name already exists in this folder" : "Súbor alebo priečinok s týmto názvom už existuje v tomto priečinku",
    "The file does not exist anymore" : "Súbor už neexistuje",
    "Copy to {target}" : "Kopírovať do {target}",
    "Move to {target}" : "Presunúť do {target}",
    "Cancelled move or copy operation" : "Zrušená operácia kopírovania alebo presunu",
    "Open folder {displayName}" : "Otvoriť priečinok {displayName}",
    "Open in Files" : "Otvoriť v súboroch",
    "Open details" : "Otvoriť detaily",
    "Could not copy {file}. {message}" : "Nepodarilo sa skopírovať {file}. {message}",
    "Could not move {file}. {message}" : "Nepodarilo sa presunúť {file}. {message}",
    "Created new folder \"{name}\"" : "Vytvorený nový priečinok \"{name}\"",
    "Filename" : "Názov súboru",
    "Unable to initialize the templates directory" : "Nemôžem inicializovať priečinok so šablónami",
    "Create new templates folder" : "Vytvoriť nový vzorový priečinok",
    "Templates" : "Šablóny",
    "Uploading \"{filename}\" failed" : "Nahrávanie \"{filename}\" zlyhalo",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} priečinok","{folderCount} priečinky","{folderCount} priečinkov","{folderCount} priečinkov"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} súbor","{fileCount} súbory","{fileCount} súborov","{fileCount} súborov"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 súbor a {folderCount} priečinok","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky","1 súbor a {folderCount} priečinky"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} súbor a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok","{fileCount} súborov a 1 priečinok"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} súborov a {folderCount} priečinkov",
    "List of favorites files and folders." : "Zoznam obľúbených súborov a priečinkov.",
    "No favorites yet" : "Zatiaľ žiadne obľúbené",
    "Files and folders you mark as favorite will show up here" : "Súbory a priečinky označené ako obľúbené budú zobrazené tu",
    "All files" : "Všetky súbory",
    "List of your files and folders." : "Zoznam vašich súborov a priečinkov.",
    "List of recently modified files and folders." : "Zoznam nedávno upravených súborov a priečinkov.",
    "No recently modified files" : "Žiadne nedávno upravené súbory",
    "Files and folders you recently modified will show up here." : "Súbory a priečinky, ktoré ste nedávno upravili sa zobrazia tu",
    "No entries found in this folder" : "V tomto priečinku nebolo nič nájdené",
    "Select all" : "Vybrať všetko",
    "Upload too large" : "Nahrávanie je príliš veľké",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Súbory, ktoré sa snažíte nahrať, presahujú maximálnu veľkosť pre nahratie súborov na tento server.",
    "Text file" : "Textový súbor",
    "New text file.txt" : "Nový text file.txt",
    "Direct link was copied (only works for users who have access to this file/folder)" : "Priamy odkaz bol skopirovaný (funguje iba pre používateľov, ktorí majú prístup k danému súboru/adresáru)",
    "Copy direct link (only works for users who have access to this file/folder)" : "Kopírovať priamy odkaz (funguje iba pre používateľov, ktorí majú prístup k tomuto súboru/priečinku)",
    "You can only favorite a single file or folder at a time" : "Do obľúbených je možné zaradovať súbory a zložky len jednotlivo",
    "\"remote user\"" : "\"vzdialený používateľ\"",
    "Search users" : "Hľadať používateľov",
    "You might not have have permissions to view it, ask the sender to share it" : "Pravdopodobne nemáte prístup, požiadajte oň odosielateľa ",
    "Set up templates folder" : "Nastaviť priečinok pre šablóny",
    "Toggle %1$s sublist" : "Prepnúť %1$s podzoznam",
    "Toggle grid view" : "Prepnúť zobrazenie mriežky",
    "Deleted files" : "Zmazané súbory",
    "Shares" : "Zdieľania",
    "Shared with others" : "Sprístupnené ostatným",
    "Shared with you" : "Vám sprístupnené",
    "Deleted shares" : "Odstránené sprístupnenia",
    "Pending shares" : "Čakajúce prístupy",
    "This file has the tag {tag}" : "Tento súbor má štítok {tag}",
    "This file has the tags {firstTags} and {lastTag}" : "Tento súbor má štítky {firstTags} a {lastTag}",
    "Select the row for {displayName}" : "Vybrať riadok pre {displayName}",
    "Open folder {name}" : "Otvoriť súbor {name}",
    "Unselect all" : "Zrušiť výber",
    "ascending" : "vzostupne",
    "descending" : "zostupne",
    "Sort list by {column} ({direction})" : "Zoradiť zoznam podľa {column} ({direction})",
    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Tento zoznam nie je úplne vykreslený z dôvodov výkonu. Súbory budú vykreslené, keď budete prechádzat zoznamom.",
    "Search for an account" : "Vyhľadať účet",
    "Choose" : "Vybrať",
    "No files or folders have been deleted yet" : "Žiadne súbory alebo priečinky neboli ešte vymazané",
    "Add" : "Pridať",
    "The files is locked" : "Súbory sú uzamknuté"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
